use Test::More tests => 5;
use strict;
use warnings;
use SOAP::WSDL::XSD::Typelib::Builtin::hexBinary;
my $hexBinary = SOAP::WSDL::XSD::Typelib::Builtin::hexBinary->new();
is $hexBinary->get_value(), undef;
$hexBinary = SOAP::WSDL::XSD::Typelib::Builtin::hexBinary->new({});
is $hexBinary->get_value(), undef;
ok $hexBinary = SOAP::WSDL::XSD::Typelib::Builtin::hexBinary->new({ value => 'a1b2c3d4' });
is "$hexBinary", "a1b2c3d4", 'stringification';
ok $hexBinary->isa('SOAP::WSDL::XSD::Typelib::Builtin::anySimpleType'), 'inheritance';