package MyElements::CountCookies;
use strict;
use warnings;

{ # BLOCK to scope variables

sub get_xmlns { 'http://www.fullerdata.com/FortuneCookie/FortuneCookie.asmx' }

__PACKAGE__->__set_name('CountCookies');
__PACKAGE__->__set_nillable();
__PACKAGE__->__set_minOccurs();
__PACKAGE__->__set_maxOccurs();
__PACKAGE__->__set_ref();

use base qw(
	SOAP::WSDL::XSD::Typelib::Element
	SOAP::WSDL::XSD::Typelib::ComplexType
);




} # end of BLOCK
1;

# __END__

=pod

=head1 NAME

MyElements::CountCookies

=head1 DESCRIPTION

Perl data type class for the XML Schema defined element
CountCookies from the namespace http://www.fullerdata.com/FortuneCookie/FortuneCookie.asmx.

=head1 METHODS

=head2 new

 my $element = MyElements::CountCookies->new($data);

Constructor. The following data structure may be passed to new():



=head1 AUTHOR

Generated by SOAP::WSDL

=cut

